@@ -1,10 +1,9 @@
-__all__ = [
-    '_Rule'
-]
+__all__ = ["_Rule"]
+
 
 class _Rule:
     r"""Class for rule representation.
-    
+
     Date:
         2021
 
@@ -30,4 +29,4 @@ class _Rule:
         """
         self.value = value
         self.min = min_val
-        self.max = max_val
\ No newline at end of file
+        self.max = max_val
